from setuptools import setup
import setuptools

setup(name='sudoku-tool',
      version='0.1',
      description='sudoku toolkit',
      url='https://github.com/Prajeeths18/Basic_Sudoku_Solver.git',
      author='girish-prajeeth',
      author_email='eragon.saphira.100@gmail.com',
      license='MIT',
      packages=setuptools.find_packages()
      )
